@@ -7,6 +7,7 @@ use fxhash::FxHashSet;
 
 #[derive(Debug, Default)]
 struct PlanBuilder {
+    /// `(src, dst)`
     tracked: FxHashSet<(ModuleId, ModuleId)>,
 
     graph: ModuleGraph,
@@ -97,6 +98,17 @@ where
             // Prevent infinite loops.
             if builder.tracked.insert((module_id, src.module_id)) {
                 self.add_to_graph(builder, src.module_id, path);
+            } else {
+                // This is a hack
+                //
+                // TODO(kdy1): Use proper logic for `builder.tracked` and remove this hack.
+                if let Some(cycle) = builder
+                    .cycles
+                    .iter_mut()
+                    .find(|cycle| cycle.contains(&module_id))
+                {
+                    cycle.push(src.module_id);
+                }
             }
         }
 
